@@ -13,9 +13,11 @@ import qualified GI.Cairo.Config as Cairo
 
 
 main :: IO ()
-main = setupBinding name version verbose overridesFile inheritedOverrides outputDir
+main = setupBinding name version pkgName pkgVersion verbose overridesFile inheritedOverrides outputDir
   where name = "Gtk"
         version = "3.0"
+        pkgName = "gi-gtk"
+        pkgVersion = "3.0.38"
         overridesFile = Just "Gtk.overrides"
         verbose = False
         outputDir = Nothing
